==> zio-aws-groundstation_2.12-5.17.103.1-sources.jar: zio/aws/groundstation/model/CreateConfigResponse.scala <==
package zio.aws.groundstation.model
import zio.aws.groundstation.model.primitives.ConfigArn
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateConfigResponse(
    configArn: Option[ConfigArn] = None,
    configId: Option[String] = None,
    configType: Option[zio.aws.groundstation.model.ConfigCapabilityType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.groundstation.model.CreateConfigResponse = {
    import CreateConfigResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.groundstation.model.CreateConfigResponse
      .builder()
      .optionallyWith(
        configArn.map(value => ConfigArn.unwrap(value): java.lang.String)
      )(_.configArn)
      .optionallyWith(configId.map(value => value: java.lang.String))(
        _.configId
      )
      .optionallyWith(configType.map(value => value.unwrap))(_.configType)
      .build()
  }
  def asReadOnly: zio.aws.groundstation.model.CreateConfigResponse.ReadOnly =
    zio.aws.groundstation.model.CreateConfigResponse.wrap(buildAwsValue())
}
object CreateConfigResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.groundstation.model.CreateConfigResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.groundstation.model.CreateConfigResponse =
      zio.aws.groundstation.model.CreateConfigResponse(
        configArn.map(value => value),
        configId.map(value => value),
        configType.map(value => value)
      )
    def configArn: Option[ConfigArn]
    def configId: Option[String]
    def configType: Option[zio.aws.groundstation.model.ConfigCapabilityType]
    def getConfigArn: ZIO[Any, AwsError, ConfigArn] =
      AwsError.unwrapOptionField("configArn", configArn)
    def getConfigId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("configId", configId)
    def getConfigType
        : ZIO[Any, AwsError, zio.aws.groundstation.model.ConfigCapabilityType] =
      AwsError.unwrapOptionField("configType", configType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.groundstation.model.CreateConfigResponse
  ) extends zio.aws.groundstation.model.CreateConfigResponse.ReadOnly {
    override val configArn: Option[ConfigArn] = scala
      .Option(impl.configArn())
      .map(value => zio.aws.groundstation.model.primitives.ConfigArn(value))
    override val configId: Option[String] =
      scala.Option(impl.configId()).map(value => value: String)
    override val configType
        : Option[zio.aws.groundstation.model.ConfigCapabilityType] = scala
      .Option(impl.configType())
      .map(value =>
        zio.aws.groundstation.model.ConfigCapabilityType.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.groundstation.model.CreateConfigResponse
  ): zio.aws.groundstation.model.CreateConfigResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-groundstation_2.12-7.21.15.1-sources.jar: zio/aws/groundstation/model/CreateConfigResponse.scala <==
package zio.aws.groundstation.model
import zio.aws.groundstation.model.primitives.ConfigArn
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateConfigResponse(
    configArn: Optional[ConfigArn] = Optional.Absent,
    configId: Optional[String] = Optional.Absent,
    configType: Optional[zio.aws.groundstation.model.ConfigCapabilityType] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.groundstation.model.CreateConfigResponse = {
    import CreateConfigResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.groundstation.model.CreateConfigResponse
      .builder()
      .optionallyWith(
        configArn.map(value => ConfigArn.unwrap(value): java.lang.String)
      )(_.configArn)
      .optionallyWith(configId.map(value => value: java.lang.String))(
        _.configId
      )
      .optionallyWith(configType.map(value => value.unwrap))(_.configType)
      .build()
  }
  def asReadOnly: zio.aws.groundstation.model.CreateConfigResponse.ReadOnly =
    zio.aws.groundstation.model.CreateConfigResponse.wrap(buildAwsValue())
}
object CreateConfigResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.groundstation.model.CreateConfigResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.groundstation.model.CreateConfigResponse =
      zio.aws.groundstation.model.CreateConfigResponse(
        configArn.map(value => value),
        configId.map(value => value),
        configType.map(value => value)
      )
    def configArn: Optional[ConfigArn]
    def configId: Optional[String]
    def configType: Optional[zio.aws.groundstation.model.ConfigCapabilityType]
    def getConfigArn: ZIO[Any, AwsError, ConfigArn] =
      AwsError.unwrapOptionField("configArn", configArn)
    def getConfigId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("configId", configId)
    def getConfigType
        : ZIO[Any, AwsError, zio.aws.groundstation.model.ConfigCapabilityType] =
      AwsError.unwrapOptionField("configType", configType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.groundstation.model.CreateConfigResponse
  ) extends zio.aws.groundstation.model.CreateConfigResponse.ReadOnly {
    override val configArn: Optional[ConfigArn] = zio.aws.core.internal
      .optionalFromNullable(impl.configArn())
      .map(value => zio.aws.groundstation.model.primitives.ConfigArn(value))
    override val configId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.configId())
      .map(value => value: String)
    override val configType
        : Optional[zio.aws.groundstation.model.ConfigCapabilityType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.configType())
        .map(value =>
          zio.aws.groundstation.model.ConfigCapabilityType.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.groundstation.model.CreateConfigResponse
  ): zio.aws.groundstation.model.CreateConfigResponse.ReadOnly = new Wrapper(
    impl
  )
}
